@@ -1,6 +1,6 @@
 package Workflow::State;
 
-# $Id: State.pm 589 2012-11-11 14:08:25Z jonasbn $
+# $Id: State.pm 454 2009-01-12 10:04:02Z jonasbn $
 
 use warnings;
 use strict;
@@ -11,10 +11,10 @@ use Workflow::Exception qw( workflow_error );
 use Workflow::Factory qw( FACTORY );
 use English qw( -no_match_vars );
 
-$Workflow::State::VERSION = '1.16';
+$Workflow::State::VERSION = '1.14';
 
 my @FIELDS   = qw( state description type );
-my @INTERNAL = qw( _test_condition_count _factory );
+my @INTERNAL = qw( _test_condition_count );
 __PACKAGE__->mk_accessors( @FIELDS, @INTERNAL );
 
 my ($log);
@@ -48,11 +48,7 @@ sub get_available_action_names {
     $self->clear_condition_cache();
 
     foreach my $action_name (@all_actions) {
-
-        #From Ivan Paponov
-        my $action_group = $self->_factory()
-            ->{_action_config}{ $self->type() }{$action_name}{'group'};
-
+        my $action_group = FACTORY->{_action_config}{$action_name}{'group'};
         if ( defined $group && length $group ) {
             if ( $action_group ne $group ) {
                 next;
@@ -163,8 +159,8 @@ sub evaluate_action {
                 # name. As the result has not been cached, we have
                 # to get the real condition with the original
                 # condition name and evaluate that
-                $condition = $self->_factory()
-                    ->get_condition( $orig_condition, $self->type() );
+                $condition = FACTORY->get_condition( $orig_condition,
+                    $self->type() );
             }
             $log->is_debug
                 && $log->debug( q{Evaluating condition '},
@@ -270,10 +266,7 @@ sub may_stop {
 # INTERNAL
 
 sub init {
-    my ( $self, $config, $factory ) = @_;
-
-    # Fallback for old style
-    $factory ||= FACTORY;
+    my ( $self, $config ) = @_;
     $log ||= get_logger();
     my $name = $config->{name};
 
@@ -283,7 +276,6 @@ sub init {
         && $log->debug("Constructing '$class' object for state $name");
 
     $self->state($name);
-    $self->_factory($factory);
 
     # Note this is the workflow type.
     $self->type( $config->{type} );
@@ -394,8 +386,8 @@ sub _create_condition_objects {
                     && $log->info(
                     "Fetching condition '$condition_info->{name}'");
                 push @condition_objects,
-                    $self->_factory()
-                    ->get_condition( $condition_info->{name}, $self->type() );
+                    FACTORY->get_condition( $condition_info->{name},
+                    $self->type() );
             }
         }
     }
@@ -414,8 +406,8 @@ sub _get_next_condition_count {
     my ($self) = @_;
 
     # Initialize if not set.
-    my $count
-        = defined $self->_test_condition_count()
+    my $count =
+        defined $self->_test_condition_count()
         ? $self->_test_condition_count() + 1
         : 1;
 
