@@ -1,6 +1,6 @@
 package Workflow::Validator::InEnumeratedType;
 
-# $Id: InEnumeratedType.pm 538 2011-01-29 17:01:04Z jonasbn $
+# $Id: InEnumeratedType.pm 454 2009-01-12 10:04:02Z jonasbn $
 
 use warnings;
 use strict;
@@ -18,8 +18,8 @@ sub _init {
             "initialized with the values you wish to ",
             "validate against using the parameter 'value'.";
     }
-    my @values
-        = ( ref $params->{value} eq 'ARRAY' )
+    my @values =
+        ( ref $params->{value} eq 'ARRAY' )
         ? @{ $params->{value} }
         : ( $params->{value} );
     $self->add_enumerated_values(@values);
